@@ -9,7 +9,7 @@ class BCryptRecipe(CompiledComponentsPythonRecipe):
     call_hostpython_via_targetpython = False
 
     def get_recipe_env(self, arch):
-        env = super(BCryptRecipe, self).get_recipe_env(arch)
+        env = super().get_recipe_env(arch)
 
         openssl_recipe = Recipe.get_recipe('openssl', self.ctx)
         env['CFLAGS'] += openssl_recipe.include_flags(arch)
